==> pillar1-0.1.7.6-py3-none-any.whl: pillar1/constants.py <==
STARCODER_BETA = """

col_name,data_type,comment
abacus_entity_type,string,
abacus_ingestion_id,string,
abacus_record_id,string,
abacus_schema_version,string,
abacus_consume_timestamp,timestamp,
abacus_partial_update_ind,boolean,
abacus_logical_delete_ind,boolean,
abacus_hard_delete_ind,boolean,
abacus_tenant_name,string,
abacus_record_hash_id,string,
source_correlation_id,string,
source_name,string,
source_id,string,
source_authoritative_ind,boolean,
source_timestamp,timestamp,
abacus_scd_key,string,
abacus_record_eff_ts,bigint,
abacus_record_exp_ts,bigint,
abacus_record_create_ts,bigint,
abacus_record_modify_ts,bigint,
abacus_record_is_active,string,
abacus_record_changed_columns,string,
abacus_ending_scd_event,string,
data_quality_result,string,
identifiers,string,
additional_source_identifiers[0-5],string,
extension_source_values[0-5],string,
claim_type,string,
claim_status,string,
claim_response_status_code,int,
claim_category,string,
claim_subcategory,string,
prescription_reference_id,string,
prescription_date_time,bigint,
billable_start_date,bigint,
billable_end_date,bigint,
claim_submitted_date_time,bigint,
claim_received_date_time,bigint,
claim_incurred_date_time,bigint,
claim_adjudication_date_time,bigint,
claim_paid_date_time,bigint,
claim_reversal_date_time,bigint,
claim_last_action_date,bigint,
claim_accepted_date,bigint,
claim_next_review_date,bigint,
is_provider_signature_on_file,boolean,
is_release_of_information_on_file,boolean,
reason_codes,string,
rejections,string,
reason_visit,string,
business_category_codes,string,
claim_reference_ids,string,
reference_ids,string,
claim_sequence_number,string,
claim_origination_code,string,
lob,string,
accident_ind,boolean,
third_party_liability_ind,boolean,
xray_enclosure_ind,boolean,
job_related_ind,boolean,
national_care_network_ind,boolean,
price_and_ship_ind,boolean,
pricing_exclusion_ind,boolean,
repricing_ind,boolean,
qualified_health_expense_ind,boolean,
personal_savings_account_noncovered_ind,boolean,
pre_price_code,string,
patient_member_source_id,string,
patient_number,int,
patient_ssn,string,
patient_full_name,string,
patient_first_name,string,
patient_last_name,string,
patient_middle_name,string,
patient_address_line_1,string,
patient_address_line_2,string,
patient_city,string,
patient_state,string,
patient_zip,int,
patient_phone,string,
patient_dob,date,
patient_gender,string,
patient_marital_status,string,
patient_employment_status,string,
patient_relationship_code,string,
patient_account_number,string,
patient_medical_record_number,string,
patient_policy_number,string,
other_payers,string,
insurance_policies,string,
other_diagnoses,string,
other_procedures,string,
disposition_messages,string,
supporting_information,string,
applied_benefits,string,
prescriptions,string,
contracts,string,
claim_split_ind,boolean,
carve_out_ind,boolean,
delivery_date,date,
daily_interest_rate,double,
scd_key,int,
drg_grouper_review_code,string,

"""

STARCODER_BETA += """
when answering the request use the information listed above only, do not make up column names and do not place additional conditions
    """

==> pillar1-0.1.7.8-py3-none-any.whl: pillar1/constants.py <==
STARCODER_BETA = """

col_name,data_type,comment
abacus_entity_type,string,
abacus_ingestion_id,string,
abacus_record_id,string,
abacus_schema_version,string,
abacus_consume_timestamp,timestamp,
abacus_partial_update_ind,boolean,
abacus_logical_delete_ind,boolean,
abacus_hard_delete_ind,boolean,
abacus_tenant_name,string,
abacus_record_hash_id,string,
source_correlation_id,string,
source_name,string,
source_id,string,
source_authoritative_ind,boolean,
source_timestamp,timestamp,
abacus_scd_key,string,
abacus_record_eff_ts,bigint,
abacus_record_exp_ts,bigint,
abacus_record_create_ts,bigint,
abacus_record_modify_ts,bigint,
abacus_record_is_active,string,
abacus_record_changed_columns,string,
abacus_ending_scd_event,string,
data_quality_result,string,
identifiers,string,
additional_source_identifiers[0-5],string,
extension_source_values[0-5],string,
claim_type,string,
claim_status,string,
claim_response_status_code,int,
claim_category,string,
claim_subcategory,string,
prescription_reference_id,string,
prescription_date_time,bigint,
billable_start_date,bigint,
billable_end_date,bigint,
claim_submitted_date_time,bigint,
claim_received_date_time,bigint,
claim_incurred_date_time,bigint,
claim_adjudication_date_time,bigint,
claim_paid_date_time,bigint,
claim_reversal_date_time,bigint,
claim_last_action_date,bigint,
claim_accepted_date,bigint,
claim_next_review_date,bigint,
is_provider_signature_on_file,boolean,
is_release_of_information_on_file,boolean,
reason_codes,string,
rejections,string,
reason_visit,string,
business_category_codes,string,
claim_reference_ids,string,
reference_ids,string,
claim_sequence_number,string,
claim_origination_code,string,
lob,string,
accident_ind,boolean,
third_party_liability_ind,boolean,
xray_enclosure_ind,boolean,
job_related_ind,boolean,
national_care_network_ind,boolean,
price_and_ship_ind,boolean,
pricing_exclusion_ind,boolean,
repricing_ind,boolean,
pre_price_code,string,
patient_member_source_id,string,
patient_number,int,
patient_ssn,string,
patient_full_name,string,
patient_first_name,string,
patient_last_name,string,
patient_middle_name,string,
patient_address_line_1,string,
patient_address_line_2,string,
patient_city,string,
patient_state,string,
patient_zip,int,
patient_phone,string,
patient_dob,date,
patient_gender,string,
patient_marital_status,string,
patient_employment_status,string,
patient_relationship_code,string,
patient_account_number,string,
patient_medical_record_number,string,
patient_policy_number,string,
insurance_policies,string,
applied_benefits,string,
prescriptions,string,
contracts,string,
claim_split_ind,boolean,
carve_out_ind,boolean,
delivery_date,date,
daily_interest_rate,double

"""

STARCODER_BETA += """
when answering the request use the information listed above only, do not make up column names and do not place additional conditions
    """
